@@ -1,16 +1,16 @@
-from threading import Thread, Event
+from threading import Event
 from subprocess import Popen, PIPE
 from processing_py.listener import Listener
 from processing_py.color import Color, color_mode
+from processing_py.requirements import check_requirements
 import sys
 import datetime as date
 import os
-import re
 
 class App():
 
 	def __init__(self,size_x = -1,size_y = -1):
-
+		check_requirements()
 		self.millis_ = 0
 		self.mouseX = 0
 		self.mouseY = 0
@@ -24,10 +24,11 @@ class App():
 		print('Starting App...',file=sys.stderr)
 		os.environ['SIZE_X'] = str(size_x)
 		os.environ['SIZE_Y'] = str(size_y)
-		self.stream = Popen(['java','-jar','processing-py.jar','i3_jython.py'],cwd=os.path.dirname(os.path.realpath(__file__))+'/processing',stdin=PIPE, stdout=PIPE,stderr=PIPE)
+		package_directory = os.path.dirname(os.path.realpath(__file__))
+		self.stream = Popen([package_directory+'/processing/jre/bin/java.exe','-jar','processing-py.jar','../i3_jython.py'],cwd=package_directory+'/processing',stdin=PIPE, stdout=PIPE,stderr=PIPE)
 		Listener(self.stream.stderr,self.isDead)
 		self.waitAnswer()
-	
+
 	def waitAnswer(self):
 		ans = self.stream.stdout.readline().decode('utf-8')
 		self.handle_answer(ans)
@@ -51,8 +52,11 @@ class App():
 
 	def sendLine(self,line):
 		line += '\n'
-		self.stream.stdin.write(line.encode('utf-8'))
-		self.stream.stdin.flush()
+		try:
+			self.stream.stdin.write(line.encode('utf-8'))
+			self.stream.stdin.flush()
+		except BaseException:
+			self.close()
 		return self.waitAnswer()
 
 	def std_function(self,name,*args):
@@ -368,10 +372,20 @@ class App():
 		self.std_function('resetMatrix')
 	
 	def exit(self):
-		self.std_function('exit')
-		self.std_function('redraw')
-		self.stream.terminate()
-		self.isDead.set()
+		try:
+			self.std_function('exit')
+			self.std_function('redraw')
+			self.stream.terminate()
+			self.isDead.set()
+		except BaseException:
+			pass
+	
+	def close(self):
+		try:
+			self.stream.terminate()
+			self.isDead.set()
+		except BaseException:
+			pass
 		
 	def day(self):
 		import datetime
