@@ -1,5 +1,7 @@
 from threading import Thread, Event
 import sys
+from clint.textui import colored, puts
+
 class Listener(Thread):
     def __init__(self,channel,isDead):
         Thread.__init__(self)
@@ -10,6 +12,6 @@ class Listener(Thread):
         while(not self.isDead.isSet()):
             msg = self.channel.readline().decode('utf-8')
             if msg != '':
-                print('>> '+msg,file=sys.stderr)
+                print(colored.yellow('>> ')+msg,file=sys.stderr)
                 
     
\ No newline at end of file
